﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.ChartView;

namespace BaseRadChartViewProject
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            // Changes the axis of the first series in the view model from Linear to Logarithmic and vice versa
            LiveDataViewModel viewModel = this.chart.DataContext as LiveDataViewModel;
            SalesViewModel firstSeries = viewModel.SalesData[0];
            NumericalAxis axis = firstSeries.VerticalAxis;
            if (axis is LinearAxis)
            {              
                firstSeries.VerticalAxis = new LogarithmicAxis() { ExponentStep = 0.2, Title = "LogarithmicAxis" };           
            }
            else if (axis is LogarithmicAxis)
            {
                firstSeries.VerticalAxis = new LinearAxis() { Title = "LinearAxis" };           
            }            
        }
    }

    public class SalesData
    {
        public DateTime X { get; set; }
        public double Y { get; set; }
    }

    public class SalesViewModel : ViewModelBase
    {
        public ObservableCollection<SalesData> Children { get; private set; }

        public NumericalAxis verticalAxis;
        public NumericalAxis VerticalAxis 
        {
            get { return this.verticalAxis; }
            set 
            {
                if (value != this.verticalAxis)
                {
                    this.verticalAxis = value;
                    OnPropertyChanged("VerticalAxis");
                }
            }
        }

        public SalesViewModel()
        {
            this.Children = new ObservableCollection<SalesData>();
        }
    }

    public class LiveDataViewModel : ViewModelBase
    {
        public ObservableCollection<SalesViewModel> SalesData { get; set; }

        public LiveDataViewModel()
        {
            this.SalesData = new ObservableCollection<SalesViewModel>();

            this.SalesData.Add(this.CreateVM());
            this.SalesData.Add(this.CreateVM());
            this.SalesData.Add(this.CreateVM());
        }
        
        private Random randomNumGen = new Random();

        public SalesViewModel CreateVM()
        {
            
            SalesViewModel vm = new SalesViewModel();

            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(0), Y = randomNumGen.Next(10, 30) });
            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(10), Y = randomNumGen.Next(10, 30) });
            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(20), Y = randomNumGen.Next(10, 30) });
            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(30), Y = randomNumGen.Next(10, 30) });
            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(40), Y = randomNumGen.Next(10, 30) });
            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(50), Y = randomNumGen.Next(10, 30) });
            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(60), Y = randomNumGen.Next(10, 30) });
            vm.Children.Add(new SalesData { X = new DateTime(2014, 3, 26).AddMinutes(70), Y = randomNumGen.Next(10, 30) });

            vm.VerticalAxis = new LinearAxis() { Title = "LinearAxis" };

            return vm;
        }
    }
}
